@@ -71,7 +71,7 @@ public:
   mutable double mcachedparam;
 public:
   KigDocument();
-  KigDocument( std::set<ObjectHolder*> objects, CoordinateSystem* coordsystem,
+  KigDocument( const std::set<ObjectHolder*> &objects, CoordinateSystem* coordsystem,
                bool showgrid = true, bool showaxes = true, bool nv = false );
   ~KigDocument();
 
