@@ -22,25 +22,29 @@
 
 #include <QBoxLayout>
 #include <QCheckBox>
+#include <QDialogButtonBox>
 #include <QLabel>
-
 #include <QVBoxLayout>
 
 KigCoordinatePrecisionDialog::KigCoordinatePrecisionDialog(bool isUserSpecified, int currentPrecision ) : QDialog()
 {
   ui = new Ui::KigCoordinatePrecisionDialog();
   QWidget *mainWidget = new QWidget(this);
+  QDialogButtonBox *buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel );
   QVBoxLayout *mainLayout = new QVBoxLayout;
   setLayout(mainLayout);
   mainLayout->addWidget(mainWidget);
+  mainLayout->addWidget( buttonBox );
   ui->setupUi(mainWidget);
-  
+
   ui->m_defaultCheckBox->setCheckState( isUserSpecified ? Qt::Unchecked : Qt::Checked) ;
   ui->m_precisionLabel->setEnabled( isUserSpecified );
   ui->m_precisionSpinBox->setEnabled( isUserSpecified );
   ui->m_precisionSpinBox->setValue( currentPrecision );
-  
+
   connect(ui->m_defaultCheckBox, &QCheckBox::stateChanged, this, &KigCoordinatePrecisionDialog::toggleCoordinateControls);
+  connect( buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept );
+  connect( buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject );
 
   show();
 }
